"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from mistralai.utils import FieldMetadata, PathParamMetadata
from typing import TypedDict
from typing_extensions import Annotated


class JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict(TypedDict):
    job_id: str
    r"""The ID of the job to analyse."""
    

class JobsAPIRoutesFineTuningGetFineTuningJobRequest(BaseModel):
    job_id: Annotated[str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))]
    r"""The ID of the job to analyse."""
    
