"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assistantmessage import AssistantMessage, AssistantMessageTypedDict
from mistralai_azure.types import BaseModel
from typing import Literal, TypedDict


ChatCompletionChoiceFinishReason = Literal["stop", "length", "model_length", "error", "tool_calls"]

class ChatCompletionChoiceTypedDict(TypedDict):
    index: int
    message: AssistantMessageTypedDict
    finish_reason: ChatCompletionChoiceFinishReason
    

class ChatCompletionChoice(BaseModel):
    index: int
    message: AssistantMessage
    finish_reason: ChatCompletionChoiceFinishReason
    
