"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
import pydantic
from typing import Final, Literal, Optional, TypedDict
from typing_extensions import Annotated, NotRequired


ArchiveFTModelOutObject = Literal["model"]

class ArchiveFTModelOutTypedDict(TypedDict):
    id: str
    archived: NotRequired[bool]
    

class ArchiveFTModelOut(BaseModel):
    id: str
    OBJECT: Annotated[Final[Optional[ArchiveFTModelOutObject]], pydantic.Field(alias="object")] = "model" # type: ignore
    archived: Optional[bool] = True
    
